summaryrefslogtreecommitdiff
path: root/rubocop/cop/gitlab/bulk_insert.rb
diff options
context:
space:
mode:
Diffstat (limited to 'rubocop/cop/gitlab/bulk_insert.rb')
-rw-r--r--rubocop/cop/gitlab/bulk_insert.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/rubocop/cop/gitlab/bulk_insert.rb b/rubocop/cop/gitlab/bulk_insert.rb
index 4c8c232043f..baaefc2533c 100644
--- a/rubocop/cop/gitlab/bulk_insert.rb
+++ b/rubocop/cop/gitlab/bulk_insert.rb
@@ -3,13 +3,13 @@
module RuboCop
module Cop
module Gitlab
# Cop that disallows the use of `Gitlab::Database.main.bulk_insert`, in favour of using
# the `BulkInsertSafe` module.
class BulkInsert < RuboCop::Cop::Cop
- MSG = 'Use the `BulkInsertSafe` concern, instead of using `Gitlab::Database.main.bulk_insert`. See https://docs.gitlab.com/ee/development/insert_into_tables_in_batches.html'
+ MSG = 'Use the `BulkInsertSafe` concern, instead of using `LegacyBulkInsert.bulk_insert`. See https://docs.gitlab.com/ee/development/insert_into_tables_in_batches.html'
def_node_matcher :raw_union?, <<~PATTERN
- (send (send (const (const _ :Gitlab) :Database) :main) :bulk_insert ...)
+ (send _ :legacy_bulk_insert ...)
PATTERN
def on_send(node)
@@ -3,13 +3,13 @@
module Cop
module Gitlab
- # Cop that disallows the use of `Gitlab::Database.main.bulk_insert`, in favour of using
+ # Cop that disallows the use of `legacy_bulk_insert`, in favour of using
# the `BulkInsertSafe` module.
class BulkInsert < RuboCop::Cop::Cop